@@ -14,6 +14,9 @@ import matplotlib.pyplot as plt
 from matplotlib.animation import FuncAnimation
 from matplotlib.widgets import Slider
 
+import streamlit as st
+from bokeh.plotting import figure
+
 
 def cycling_CCCV(file_name,cycle_num):
     '''
@@ -297,7 +300,7 @@ def dynamic_dqdv(file_name):
     fig1, ax1 = plt.subplots()
     dqdvc, = ax1.plot([], [], lw=2)
     dqdvd, = ax1.plot([], [], lw=2)   
-    cycle2 = fig1.text(0.85,0.85,'',ha='right', va='top', fontsize=24)
+    cycle2 = fig1.text(0.4,0.85,'',ha='right', va='top', fontsize=24)
     colors = plt.get_cmap('coolwarm', N)
     
     def animate_1(i):
@@ -539,6 +542,29 @@ def diff_cap_st(file_name,cycle_num):
 
     fig = st.bokeh_chart(dqdv_fig)
     return (fig)
+def Nyquist_plot_st(text_file):
+    '''
+    
+    Parameters
+    ----------
+    df : DataFrame
+        dataframe that is processed by impedance_data_processing() .
+    Returns
+    -------
+    fig : figure
+        Nyquist_plot for the visualization.
+    '''
+    df=impedance_data_processing(text_file)
+    
+    plt.plot(df['Z1'],-df['Z2'])
+    plt.xlabel('Z1')
+    plt.ylabel('-Z1')
+    plt.show()
 
+    eis_fig = figure(title='', x_axis_label='Z1', y_axis_label='-Z1')
+    eis_fig.line(df['Z1'],-df['Z2'], legend_label='', line_width=2)
+
+    fig = st.bokeh_chart(eis_fig)
+    return (fig)
 
     
